package Meurs
  connector bfc
    Real p(unit = "torr");
    flow Real q(unit = "ml/s");
    annotation(Icon(graphics = {Rectangle(origin = {-1, 0}, extent = {{-97, 98}, {97, -98}})}));
  end bfc;

  connector bfc_in
    extends Meurs.bfc;
    annotation(Icon(graphics = {Rectangle(origin = {0, -1}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-98, 99}, {98, -99}})}));
  end bfc_in;

  connector bfc_out
    extends Meurs.bfc;
    annotation(Icon(graphics = {Rectangle(origin = {-1, 0}, fillColor = {141, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-99, 100}, {99, -100}})}));
  end bfc_out;

  model OnePort
    bfc_in In annotation(Placement(visible = true, transformation(origin = {-84, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out Out annotation(Placement(visible = true, transformation(origin = {88, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Real q = In.q;
    Real dp = In.p - Out.p;
  equation
    In.q + Out.q = 0;
    annotation(Icon(graphics = {Rectangle(origin = {1, 0}, extent = {{-89, 82}, {89, -82}})}));
  end OnePort;

  model Resistor
    extends Meurs.OnePort;
    parameter Real R;
  equation
    dp = R * q;
    annotation(Icon(graphics = {Rectangle(origin = {1, -1}, fillColor = {243, 16, 16}, fillPattern = FillPattern.Backward, extent = {{-85, 77}, {85, -77}})}));
  end Resistor;

  model ResistorVariable
    extends Meurs.OnePort;
    Modelica.Blocks.Interfaces.RealInput R annotation(Placement(visible = true, transformation(origin = {-84, 74}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-80, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    dp = R * q;
    annotation(Icon(graphics = {Rectangle(origin = {0, -2}, fillColor = {229, 20, 20}, fillPattern = FillPattern.CrossDiag, extent = {{-82, 70}, {82, -70}})}));
  end ResistorVariable;

  model Inertance
    extends Meurs.OnePort;
    Modelica.Blocks.Interfaces.RealInput L annotation(Placement(visible = true, transformation(origin = {-78, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-78, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    dp = der(q) * L;
  end Inertance;

  model ElasticCompartment
    bfc_in In annotation(Placement(visible = true, transformation(origin = {0, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {0, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput ExternalPressure annotation(Placement(visible = true, transformation(origin = {-8, 64}, extent = {{-32, -32}, {32, 32}}, rotation = 0), iconTransformation(origin = {4, 76}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput Elastance annotation(Placement(visible = true, transformation(origin = {-84, 66}, extent = {{-32, -32}, {32, 32}}, rotation = 0), iconTransformation(origin = {-72, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Volume(start = V0) annotation(Placement(visible = true, transformation(origin = {70, -76}, extent = {{-34, -34}, {34, 34}}, rotation = 0), iconTransformation(origin = {84, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput StressedVolume annotation(Placement(visible = true, transformation(origin = {2, -72}, extent = {{-30, -30}, {30, 30}}, rotation = 0), iconTransformation(origin = {16, -86}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Pressure annotation(Placement(visible = true, transformation(origin = {-61, -69}, extent = {{-31, -31}, {31, 31}}, rotation = 0), iconTransformation(origin = {-46, -84}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    parameter Real V0(unit = "ml") "initial volume if elastic compartment in ml";
    parameter Real UnstressedVolume(unit = "ml") "unstressed volume in ml";
    Real TransmuralPressure(unit = "mmHg");
  equation
    
    In.p = Pressure;
    TransmuralPressure = Pressure - ExternalPressure;
    StressedVolume = Volume - UnstressedVolume;
    if StressedVolume > 0 then
      TransmuralPressure = Elastance * StressedVolume;
    else
      TransmuralPressure = 0;
    end if;
    der(Volume) = In.q;

    annotation(Icon(graphics = {Ellipse(origin = {1, 0}, lineColor = {53, 49, 1}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Sphere, extent = {{-97, 98}, {97, -98}}, endAngle = 360)}));
  end ElasticCompartment;

  model CardiacValve
    extends Meurs.OnePort;
    Real s;
    Boolean open;
    parameter Real rOpen = 0.003 "maly odpor, ikdyz je chlopenotevrena";
    parameter Real gClose = 0 "konduktance";
  equation
    open = s > 0;
    if open then
      dp = s * rOpen;
      s = q;
    else
      dp = s;
      q = s * gClose;
    end if;
    annotation(Icon(graphics = {Polygon(origin = {4, 0}, fillColor = {219, 146, 109}, fillPattern = FillPattern.Solid, points = {{-46, 60}, {-46, -60}, {14, -20}, {14, -60}, {34, -60}, {34, 60}, {14, 60}, {14, 20}, {-46, 60}, {-46, 60}})}));
  end CardiacValve;

  model HeartIntervals
    Modelica.Blocks.Interfaces.RealInput HR annotation(Placement(visible = true, transformation(origin = {-84, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-76, 56}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Tas annotation(Placement(visible = true, transformation(origin = {84, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {84, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Tav annotation(Placement(visible = true, transformation(origin = {94, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {86, 12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Tvs annotation(Placement(visible = true, transformation(origin = {104, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {86, -26}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput T0 annotation(Placement(visible = true, transformation(origin = {114, 80}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {86, -58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    discrete Real HP;
    Boolean b;
  equation
    b = time - pre(T0) >= pre(HP);
    when {initial(), b} then
      T0 = time;
      HP = 60 / HR;
      Tas = 0.03 + 0.09 * HP;
      Tav = 0.01;
      Tvs = 0.16 + 0.2 * HP;
    end when;
    annotation(Icon(graphics = {Rectangle(lineColor = {170, 0, 0}, lineThickness = 1, extent = {{-80, 80}, {80, -80}}), Line(origin = {-60, -20.5}, points = {{0, 40.5}, {0, -39.5}, {0, -39.5}}, color = {170, 0, 0}, thickness = 1), Line(origin = {-40, -22}, points = {{0, 42}, {0, 6}, {0, -38}}, color = {170, 0, 0}, thickness = 1), Line(origin = {-20, -21}, points = {{0, 41}, {0, -39}}, color = {170, 0, 0}, thickness = 1), Line(origin = {6, -21}, points = {{0, 41}, {0, -39}}, color = {170, 0, 0}, thickness = 1), Line(origin = {40, -21}, points = {{0, 41}, {0, -39}}, color = {170, 0, 0}, thickness = 1), Text(origin = {-8, 67}, extent = {{-36, 5}, {50, -17}}, textString = "HeartIntervals")}), uses(Modelica(version = "3.2.1")));
  end HeartIntervals;

  model AtrialElastance
    Modelica.Blocks.Interfaces.RealInput Tas annotation(Placement(visible = true, transformation(origin = {-80, 54}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-88, 50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput T0 annotation(Placement(visible = true, transformation(origin = {-70, 64}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-88, -50}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Et annotation(Placement(visible = true, transformation(origin = {82, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {95, -1}, extent = {{-15, -15}, {15, 15}}, rotation = 0)));
    parameter Real EMIN = 0.05 "Diastolic Elastance";
    parameter Real EMAX = 0.15 "Maximum systolic Elastance";
  equation
    if time - T0 < Tas then
      Et = EMIN + (EMAX - EMIN) * sin(Modelica.Constants.pi * (time - T0) / Tas);
    else
      Et = EMIN;
    end if;
    annotation(Icon(graphics = {Rectangle(lineColor = {0, 85, 0}, lineThickness = 2, extent = {{-80, 80}, {80, -80}}), Line(origin = {4.95, 10.95}, points = {{-64.9527, -30.9527}, {-62.9527, -10.9527}, {-56.9527, 7.04727}, {-44.9527, 25.0473}, {-30.9527, 31.0473}, {-10.9527, 31.0473}, {1.04727, 25.0473}, {11.0473, 9.04727}, {15.0473, -10.9527}, {17.0473, -30.9527}, {65.0473, -30.9527}, {65.0473, -30.9527}}, color = {0, 85, 0}, thickness = 2), Text(origin = {-12, 71}, extent = {{-28, 5}, {42, -21}}, textString = "AtrialElastance")}, coordinateSystem(initialScale = 0.1)), uses(Modelica(version = "3.2.1")));
  end AtrialElastance;

  model VentricularElastance
    Modelica.Blocks.Interfaces.RealInput Tas annotation(Placement(visible = true, transformation(origin = {-78, 60}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-88, 68}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput Tav annotation(Placement(visible = true, transformation(origin = {-68, 70}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-88, 26}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput Tvs annotation(Placement(visible = true, transformation(origin = {-58, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-88, -16}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput T0 annotation(Placement(visible = true, transformation(origin = {-48, 90}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-88, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Et annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {95, 41}, extent = {{-15, -15}, {15, 15}}, rotation = 0)));
    Real Et0;
    Real HeartInterval;
    constant Real Kn = 0.57923032735652;
    parameter Real EMIN = 0;
    parameter Real EMAX = 1;
  equation
    HeartInterval = time - T0;
    Et = EMIN + (EMAX - EMIN) * Et0;
    if HeartInterval >= Tas + Tav and HeartInterval < Tas + Tav + Tvs then
      Et0 = (HeartInterval - (Tas + Tav)) / Tvs * sin(Modelica.Constants.pi * (HeartInterval - (Tas + Tav)) / Tvs) / Kn;
    else
      Et0 = 0;
    end if;
    annotation(Icon(graphics = {Rectangle(origin = {0, 1}, lineColor = {0, 85, 0}, lineThickness = 2, extent = {{-80, 79}, {80, -81}}), Line(origin = {5.9, 2.9}, points = {{-65.9034, -42.9034}, {-61.9034, -24.9034}, {-55.9034, -4.90344}, {-47.9034, 15.0966}, {-39.9034, 29.0966}, {-29.9034, 39.0966}, {-19.9034, 43.0966}, {-5.90344, 43.0966}, {-1.90344, 41.0966}, {2.09656, 31.0966}, {4.0966, 19.0966}, {6.0966, 5.09656}, {8.09656, -6.90344}, {10.0966, -20.9034}, {14.0966, -32.9034}, {20.0966, -42.9034}, {62.0966, -42.9034}}, color = {0, 85, 0}, thickness = 2), Text(origin = {-4, 71}, extent = {{-50, 5}, {54, -19}}, textString = "VentricularElastance")}, coordinateSystem(initialScale = 0.1)), uses(Modelica(version = "3.2.1")), Diagram, version = "");
  end VentricularElastance;

  model LeftHeartPart
    Meurs.bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-82, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Meurs.bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {84, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    ElasticCompartment elasticCompartment1(UnstressedVolume = 30, V0 = 81)  annotation(Placement(visible = true, transformation(origin = {-47, 1}, extent = {{-13, -13}, {13, 13}}, rotation = 0)));
    Meurs.ElasticCompartment elasticCompartment2(UnstressedVolume = 60, V0 = 86)  annotation(Placement(visible = true, transformation(origin = {25, 1}, extent = {{-13, -13}, {13, 13}}, rotation = 0)));
    Meurs.CardiacValve cardiacValve1 annotation(Placement(visible = true, transformation(origin = {-14, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Meurs.CardiacValve cardiacValve2 annotation(Placement(visible = true, transformation(origin = {60, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    HeartIntervals heartIntervals1 annotation(Placement(visible = true, transformation(origin = {-49, -55}, extent = {{-23, -23}, {23, 23}}, rotation = 0)));
    AtrialElastance atrialElastance1(EMAX = 0.28, EMIN = 0.12)  annotation(Placement(visible = true, transformation(origin = {21, -39}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
    VentricularElastance ventricularElastance1(EMAX = 4, EMIN = 0.09)  annotation(Placement(visible = true, transformation(origin = {21, -79}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput HR annotation(Placement(visible = true, transformation(origin = {-98, -42}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-72, 54}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput ExtP annotation(Placement(visible = true, transformation(origin = {-94, 76}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-72, -52}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    connect(cardiacValve2.Out, bfc_out1) annotation(Line(points = {{70, 2}, {90, 2}}));
    connect(elasticCompartment1.In, bfc_in1) annotation(Line(points = {{-46, 2}, {-90, 2}}));
    connect(ventricularElastance1.Et, elasticCompartment2.Elastance) annotation(Line(points = {{40, -72}, {58, -72}, {58, -14}, {8, -14}, {8, 10}, {16, 10}, {16, 12}}, color = {0, 0, 127}));
    connect(atrialElastance1.Et, elasticCompartment1.Elastance) annotation(Line(points = {{40, -40}, {50, -40}, {50, -20}, {-64, -20}, {-64, 10}, {-56, 10}, {-56, 12}}, color = {0, 0, 127}));
    connect(heartIntervals1.T0, atrialElastance1.T0) annotation(Line(points = {{-30, -68}, {-4, -68}, {-4, -48}, {4, -48}, {4, -48}}, color = {0, 0, 127}));
    connect(heartIntervals1.T0, ventricularElastance1.T0) annotation(Line(points = {{-30, -68}, {-20, -68}, {-20, -90}, {4, -90}, {4, -90}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tvs, ventricularElastance1.Tvs) annotation(Line(points = {{-30, -60}, {-16, -60}, {-16, -82}, {4, -82}, {4, -82}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tav, ventricularElastance1.Tav) annotation(Line(points = {{-30, -52}, {-12, -52}, {-12, -74}, {4, -74}, {4, -74}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tas, ventricularElastance1.Tas) annotation(Line(points = {{-30, -44}, {-8, -44}, {-8, -66}, {4, -66}, {4, -66}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tas, atrialElastance1.Tas) annotation(Line(points = {{-30, -44}, {-10, -44}, {-10, -30}, {4, -30}, {4, -30}}, color = {0, 0, 127}));
    connect(ExtP, elasticCompartment2.ExternalPressure) annotation(Line(points = {{-94, 76}, {24, 76}, {24, 10}, {26, 10}}, color = {0, 0, 127}));
    connect(ExtP, elasticCompartment1.ExternalPressure) annotation(Line(points = {{-94, 76}, {-48, 76}, {-48, 10}, {-46, 10}}, color = {0, 0, 127}));
    connect(HR, heartIntervals1.HR) annotation(Line(points = {{-98, -42}, {-68, -42}, {-68, -42}, {-66, -42}}, color = {0, 0, 127}));
    connect(elasticCompartment2.In, cardiacValve2.In) annotation(Line(points = {{26, 2}, {51, 2}}));
    connect(cardiacValve1.Out, elasticCompartment2.In) annotation(Line(points = {{-4, 2}, {25, 2}, {25, 1}}));
    connect(elasticCompartment1.In, cardiacValve1.In) annotation(Line(points = {{-46, 2}, {-23, 2}}));
    annotation(Diagram(coordinateSystem(initialScale = 0.1)), uses(Modelica(version = "3.2.1")), Icon(graphics = {Rectangle(lineColor = {170, 0, 0}, lineThickness = 2, extent = {{-80, 80}, {80, -80}}), Line(origin = {-0.01, 5.21}, points = {{-1.99478, 14.788}, {4.00522, 22.788}, {10.0052, 30.788}, {18.0052, 34.788}, {26.0052, 30.788}, {32.0052, 20.788}, {34.0052, 12.788}, {0.00521909, -37.212}, {-29.9948, 10.788}, {-33.9948, 20.788}, {-31.9948, 30.788}, {-23.9948, 36.788}, {-11.9948, 34.788}, {-7.99478, 26.788}, {-3.99478, 16.788}, {-1.99478, 14.788}}, color = {170, 0, 0}, thickness = 2)}));
  end LeftHeartPart;

  model RigthHeartPart
    Meurs.bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-82, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Meurs.bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {84, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    ElasticCompartment elasticCompartment1(UnstressedVolume = 30, V0 = 136)  annotation(Placement(visible = true, transformation(origin = {-47, 1}, extent = {{-13, -13}, {13, 13}}, rotation = 0)));
    Meurs.ElasticCompartment elasticCompartment2(UnstressedVolume = 40, V0 = 96)  annotation(Placement(visible = true, transformation(origin = {25, 1}, extent = {{-13, -13}, {13, 13}}, rotation = 0)));
    Meurs.CardiacValve cardiacValve1 annotation(Placement(visible = true, transformation(origin = {-14, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Meurs.CardiacValve cardiacValve2 annotation(Placement(visible = true, transformation(origin = {60, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Meurs.HeartIntervals heartIntervals1 annotation(Placement(visible = true, transformation(origin = {-51, -55}, extent = {{-23, -23}, {23, 23}}, rotation = 0)));
    AtrialElastance atrialElastance1(EMAX = 0.06, EMIN = 0.05)  annotation(Placement(visible = true, transformation(origin = {21, -39}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
    VentricularElastance ventricularElastance1(EMAX = 0.49, EMIN = 0.057)  annotation(Placement(visible = true, transformation(origin = {21, -79}, extent = {{-19, -19}, {19, 19}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput HR annotation(Placement(visible = true, transformation(origin = {-98, -42}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-72, 54}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput ExtP annotation(Placement(visible = true, transformation(origin = {-94, 76}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-72, -52}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    connect(ventricularElastance1.Et, elasticCompartment2.Elastance) annotation(Line(points = {{40, -72}, {56, -72}, {56, -14}, {8, -14}, {8, 12}, {16, 12}, {16, 12}}, color = {0, 0, 127}));
    connect(HR, heartIntervals1.HR) annotation(Line(points = {{-98, -42}, {-68, -42}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tas, atrialElastance1.Tas) annotation(Line(points = {{-32, -43.5}, {-10, -43.5}, {-10, -30}, {4, -30}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tas, ventricularElastance1.Tas) annotation(Line(points = {{-32, -43.5}, {-8, -43.5}, {-8, -66}, {4, -66}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tav, ventricularElastance1.Tav) annotation(Line(points = {{-31, -52}, {-12, -52}, {-12, -74}, {4, -74}}, color = {0, 0, 127}));
    connect(heartIntervals1.Tvs, ventricularElastance1.Tvs) annotation(Line(points = {{-31, -61}, {-16, -61}, {-16, -82}, {4, -82}}, color = {0, 0, 127}));
    connect(heartIntervals1.T0, ventricularElastance1.T0) annotation(Line(points = {{-31, -68}, {-20, -68}, {-20, -90}, {4, -90}}, color = {0, 0, 127}));
    connect(heartIntervals1.T0, atrialElastance1.T0) annotation(Line(points = {{-31, -68}, {-4, -68}, {-4, -48}, {4, -48}}, color = {0, 0, 127}));
    connect(cardiacValve2.Out, bfc_out1) annotation(Line(points = {{70, 2}, {90, 2}}));
    connect(elasticCompartment1.In, bfc_in1) annotation(Line(points = {{-46, 2}, {-90, 2}}));
    connect(atrialElastance1.Et, elasticCompartment1.Elastance) annotation(Line(points = {{40, -40}, {50, -40}, {50, -20}, {-64, -20}, {-64, 10}, {-56, 10}, {-56, 12}}, color = {0, 0, 127}));
    connect(ExtP, elasticCompartment2.ExternalPressure) annotation(Line(points = {{-94, 76}, {24, 76}, {24, 10}, {26, 10}}, color = {0, 0, 127}));
    connect(ExtP, elasticCompartment1.ExternalPressure) annotation(Line(points = {{-94, 76}, {-48, 76}, {-48, 10}, {-46, 10}}, color = {0, 0, 127}));
    connect(elasticCompartment2.In, cardiacValve2.In) annotation(Line(points = {{26, 2}, {51, 2}}));
    connect(cardiacValve1.Out, elasticCompartment2.In) annotation(Line(points = {{-4, 2}, {25, 2}, {25, 1}}));
    connect(elasticCompartment1.In, cardiacValve1.In) annotation(Line(points = {{-46, 2}, {-23, 2}}));
    annotation(Diagram(coordinateSystem(initialScale = 0.1)), uses(Modelica(version = "3.2.1")), Icon(graphics = {Rectangle(lineColor = {170, 0, 0}, lineThickness = 2, extent = {{-80, 80}, {80, -80}}), Line(origin = {-0.01, 5.21}, points = {{-1.99478, 14.788}, {4.00522, 22.788}, {10.0052, 30.788}, {18.0052, 34.788}, {26.0052, 30.788}, {32.0052, 20.788}, {34.0052, 12.788}, {0.00521909, -37.212}, {-29.9948, 10.788}, {-33.9948, 20.788}, {-31.9948, 30.788}, {-23.9948, 36.788}, {-11.9948, 34.788}, {-7.99478, 26.788}, {-3.99478, 16.788}, {-1.99478, 14.788}}, color = {170, 0, 0}, thickness = 2)}));
  end RigthHeartPart;

  model Arterial
    ElasticCompartment elasticCompartment1(UnstressedVolume = 140, V0 = 201)  annotation(Placement(visible = true, transformation(origin = {-58, -10}, extent = {{-14, -14}, {14, 14}}, rotation = 0)));
    ElasticCompartment elasticCompartment2(UnstressedVolume = 370, V0 = 519)  annotation(Placement(visible = true, transformation(origin = {50, -10}, extent = {{-14, -14}, {14, 14}}, rotation = 0)));
    Meurs.bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-84, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Meurs.bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {82, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Inertance inertance1 annotation(Placement(visible = true, transformation(origin = {-20, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Resistor resistor1(R = 0.06)  annotation(Placement(visible = true, transformation(origin = {12, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealInput IntrathoracicPressure annotation(Placement(visible = true, transformation(origin = {-80, 82}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-72, 56}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const(k = 1.41) annotation(Placement(visible = true, transformation(origin = {-84, 28}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const1(k = 0.556) annotation(Placement(visible = true, transformation(origin = {-16, 22}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const2(k = 0) annotation(Placement(visible = true, transformation(origin = {-18, 54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const3(k = 0.0007) annotation(Placement(visible = true, transformation(origin = {-46, 18}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(inertance1.L, const3.y) annotation(Line(points = {{-28, -2}, {-32, -2}, {-32, 18}, {-34, 18}, {-34, 18}}, color = {0, 0, 127}));
    connect(const2.y, elasticCompartment2.ExternalPressure) annotation(Line(points = {{-6, 54}, {50, 54}, {50, 1}, {51, 1}}, color = {0, 0, 127}));
    connect(const1.y, elasticCompartment2.Elastance) annotation(Line(points = {{-4, 22}, {24, 22}, {24, 2}, {40, 2}, {40, 1}}, color = {0, 0, 127}));
    connect(elasticCompartment2.In, bfc_out1) annotation(Line(points = {{50, -10}, {90, -10}}));
    connect(resistor1.Out, elasticCompartment2.In) annotation(Line(points = {{22, -10}, {50, -10}}));
    connect(IntrathoracicPressure, elasticCompartment1.ExternalPressure) annotation(Line(points = {{-80, 82}, {-58, 82}, {-58, 0}, {-58, 0}}, color = {0, 0, 127}));
    connect(const.y, elasticCompartment1.Elastance) annotation(Line(points = {{-72, 28}, {-70, 28}, {-70, 0}, {-68, 0}}, color = {0, 0, 127}));
    connect(resistor1.In, inertance1.Out) annotation(Line(points = {{2, -10}, {-12, -10}, {-12, -10}, {-10, -10}}));
    connect(inertance1.In, elasticCompartment1.In) annotation(Line(points = {{-28, -10}, {-58, -10}}));
    connect(elasticCompartment1.In, bfc_in1) annotation(Line(points = {{-58, -10}, {-90, -10}}));
    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics = {Rectangle(origin = {-1, 0}, lineColor = {0, 85, 127}, lineThickness = 2, extent = {{-81, 80}, {81, -80}}), Ellipse(origin = {-3, -1}, lineColor = {216, 216, 216}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-35, -41}, {35, 41}}, endAngle = 360), Text(origin = {-3, 56}, extent = {{-33, 12}, {33, -12}}, textString = "Arterial")}));
  end Arterial;

  model Tissues
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Resistor resistor1(R = 0.8)  annotation(Placement(visible = true, transformation(origin = {-54, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Resistor resistor2(R = 0.2)  annotation(Placement(visible = true, transformation(origin = {56, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    ElasticCompartment elasticCompartment1(UnstressedVolume = 185, V0 = 281)  annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-16, -16}, {16, 16}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 0.262)  annotation(Placement(visible = true, transformation(origin = {-60, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const1(k = 0)  annotation(Placement(visible = true, transformation(origin = {-30, 82}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(const1.y, elasticCompartment1.ExternalPressure) annotation(Line(points = {{-18, 82}, {-4, 82}, {-4, 12}, {0, 12}, {0, 12}}, color = {0, 0, 127}));
    connect(elasticCompartment1.Elastance, const.y) annotation(Line(points = {{-12, 12}, {-42, 12}, {-42, 58}, {-48, 58}, {-48, 58}}, color = {0, 0, 127}));
    connect(resistor2.Out, bfc_out1) annotation(Line(points = {{66, 0}, {88, 0}, {88, 2}, {90, 2}}));
    connect(resistor2.In, elasticCompartment1.In) annotation(Line(points = {{46, 0}, {0, 0}, {0, 0}, {0, 0}}));
    connect(resistor1.Out, elasticCompartment1.In) annotation(Line(points = {{-44, 0}, {0, 0}, {0, 0}, {0, 0}}));
    connect(resistor1.In, bfc_in1) annotation(Line(points = {{-64, 0}, {-84, 0}, {-84, 2}, {-90, 2}}));
    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics = {Polygon(origin = {-0.91, 17}, lineColor = {255, 170, 255}, lineThickness = 1.5, points = {{-85.0896, -11}, {84.9104, -11}, {70.9104, 5}, {50.9104, 9}, {24.9104, 11}, {2.91044, 11}, {-23.0896, 11}, {-45.0896, 9}, {-65.0896, 3}, {-85.0896, -11}, {-85.0896, -11}}), Polygon(origin = {1.03, -13}, lineColor = {255, 170, 255}, lineThickness = 1.5, points = {{-83.0306, 12.9979}, {82.9694, 12.9979}, {72.9694, -1.00205}, {62.9694, -5.00205}, {46.9694, -9.0021}, {36.9694, -11.0021}, {18.9694, -13.0021}, {2.96942, -13.0021}, {-19.0306, -13.0021}, {-37.0306, -11.0021}, {-49.0306, -9.00205}, {-69.0306, -3.00205}, {-69.0306, -3.00205}, {-69.0306, -3.00205}, {-69.0306, -3.00205}, {-83.0306, 12.9979}})}));
  end Tissues;

  model Vena
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-82, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {78, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment elasticCompartment1(UnstressedVolume = 1000, V0 = 1546)  annotation(Placement(visible = true, transformation(origin = {-53, -11}, extent = {{-15, -15}, {15, 15}}, rotation = 0)));
  Resistor resistor1(R = 0.09)  annotation(Placement(visible = true, transformation(origin = {-18, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment elasticCompartment2(UnstressedVolume = 1190, V0 = 1523)  annotation(Placement(visible = true, transformation(origin = {20, -14}, extent = {{-14, -14}, {14, 14}}, rotation = 0)));
  Resistor resistor2(R = 0.003)  annotation(Placement(visible = true, transformation(origin = {52, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealInput u annotation(Placement(visible = true, transformation(origin = {-82, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-72, 52}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 0)  annotation(Placement(visible = true, transformation(origin = {-84, 48}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const1(k = 0.0169)  annotation(Placement(visible = true, transformation(origin = {-86, 16}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const2(k = 0.0182)  annotation(Placement(visible = true, transformation(origin = {-10, 52}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(const.y, elasticCompartment1.ExternalPressure) annotation(Line(points = {{-72, 48}, {-54, 48}, {-54, 0}, {-52, 0}}, color = {0, 0, 127}));
    connect(const1.y, elasticCompartment1.Elastance) annotation(Line(points = {{-74, 16}, {-70, 16}, {-70, 2}, {-64, 2}, {-64, 0}}, color = {0, 0, 127}));
    connect(const2.y, elasticCompartment2.Elastance) annotation(Line(points = {{2, 52}, {4, 52}, {4, -2}, {10, -2}, {10, -4}}, color = {0, 0, 127}));
    connect(u, elasticCompartment2.ExternalPressure) annotation(Line(points = {{-82, 80}, {20, 80}, {20, -4}, {20, -4}}, color = {0, 0, 127}));
    connect(resistor2.Out, bfc_out1) annotation(Line(points = {{62, -12}, {86, -12}, {86, -10}, {90, -10}}));
    connect(elasticCompartment2.In, resistor2.In) annotation(Line(points = {{20, -14}, {40, -14}, {40, -12}, {42, -12}, {42, -12}}));
    connect(resistor1.Out, elasticCompartment2.In) annotation(Line(points = {{-8, -12}, {20, -12}, {20, -14}, {20, -14}}));
    connect(resistor1.In, elasticCompartment1.In) annotation(Line(points = {{-28, -12}, {-52, -12}, {-52, -10}, {-52, -10}}));
    connect(elasticCompartment1.In, bfc_in1) annotation(Line(points = {{-52, -10}, {-88, -10}, {-88, -10}, {-90, -10}}));
    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics = {Rectangle(origin = {1, 0}, lineColor = {0, 85, 127}, lineThickness = 2, extent = {{-81, 80}, {79, -80}}), Ellipse(origin = {-1, -6}, lineColor = {85, 85, 255}, fillColor = {85, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-41, 44}, {41, -44}}, endAngle = 360), Text(origin = {-7, 60}, extent = {{-13, 10}, {25, -18}}, textString = "Vena")}));
  end Vena;

  model Circulation
    bfc_in bfc_in1 annotation(Placement(visible = true, transformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    bfc_out bfc_out1 annotation(Placement(visible = true, transformation(origin = {90, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -2}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  ElasticCompartment elasticCompartment1(UnstressedVolume = 50, V0 = 103)  annotation(Placement(visible = true, transformation(origin = {-50, 0}, extent = {{-16, -16}, {16, 16}}, rotation = 0)));
  Meurs.ElasticCompartment elasticCompartment2(UnstressedVolume = 350, V0 = 508) annotation(Placement(visible = true, transformation(origin = {22, 0}, extent = {{-16, -16}, {16, 16}}, rotation = 0)));
  Resistor resistor1(R = 0.11)  annotation(Placement(visible = true, transformation(origin = {-14, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Resistor resistor2(R = 0.003)  annotation(Placement(visible = true, transformation(origin = {60, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Interfaces.RealInput IntrathoracicPressure annotation(Placement(visible = true, transformation(origin = {-76, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-72, 58}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 0.233)  annotation(Placement(visible = true, transformation(origin = {-88, 38}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const1(k = 0.0455)  annotation(Placement(visible = true, transformation(origin = {-12, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(resistor1.Out, elasticCompartment2.In) annotation(Line(points = {{-4, 0}, {22, 0}}));
    connect(elasticCompartment2.In, resistor2.In) annotation(Line(points = {{22, 0}, {52, 0}}));
    connect(IntrathoracicPressure, elasticCompartment2.ExternalPressure) annotation(Line(points = {{-76, 78}, {23, 78}, {23, 12}}, color = {0, 0, 127}));
    connect(const1.y, elasticCompartment2.Elastance) annotation(Line(points = {{0, 36}, {4, 36}, {4, 12}, {10, 12}}, color = {0, 0, 127}));
    connect(const.y, elasticCompartment1.Elastance) annotation(Line(points = {{-76, 38}, {-68, 38}, {-68, 12}, {-62, 12}, {-62, 12}}, color = {0, 0, 127}));
    connect(IntrathoracicPressure, elasticCompartment1.ExternalPressure) annotation(Line(points = {{-76, 78}, {-50, 78}, {-50, 12}, {-50, 12}}, color = {0, 0, 127}));
    connect(resistor2.Out, bfc_out1) annotation(Line(points = {{70, 0}, {88, 0}, {88, -2}, {90, -2}}));
    connect(elasticCompartment1.In, resistor1.In) annotation(Line(points = {{-50, 0}, {-24, 0}, {-24, 0}, {-24, 0}}));
    connect(bfc_in1, elasticCompartment1.In) annotation(Line(points = {{-90, 0}, {-50, 0}, {-50, 0}, {-50, 0}}));
    annotation(uses(Modelica(version = "3.2.1")), Icon(graphics = {Ellipse(origin = {-60, -5}, lineColor = {85, 170, 255}, lineThickness = 1.5, extent = {{60, 79}, {-26, -73}}, endAngle = 360), Ellipse(origin = {26, -7}, lineColor = {85, 170, 255}, lineThickness = 1.5, extent = {{60, 79}, {-26, -73}}, endAngle = 360), Line(origin = {0, 45}, points = {{0, 35}, {0, -35}, {0, -35}}, color = {85, 170, 255}, thickness = 1.5)}));
  end Circulation;

  model VanMeurs
  Meurs.RigthHeartPart rigthHeartPart1 annotation(Placement(visible = true, transformation(origin = {-62, 36}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Meurs.LeftHeartPart leftHeartPart1 annotation(Placement(visible = true, transformation(origin = {60, 36}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  Arterial arterial1 annotation(Placement(visible = true, transformation(origin = {53, -59}, extent = {{-19, -19}, {19, 19}}, rotation = 180)));
  Meurs.Tissues tissues1 annotation(Placement(visible = true, transformation(origin = {3, -59}, extent = {{-17, -17}, {17, 17}}, rotation = 180)));
  Vena vena1 annotation(Placement(visible = true, transformation(origin = {-52, -60}, extent = {{-20, -20}, {20, 20}}, rotation = 180)));
  Modelica.Blocks.Sources.Constant const2(k = -4) annotation(Placement(visible = true, transformation(origin = {-6, 24}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Circulation circulation1 annotation(Placement(visible = true, transformation(origin = {3.55271e-15, 78}, extent = {{-22, -22}, {22, 22}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const3(k = 72) annotation(Placement(visible = true, transformation(origin = {-68, -12}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(const3.y, leftHeartPart1.ExtP) annotation(Line(points = {{-56, -12}, {34, -12}, {34, 24}, {42, 24}, {42, 26}, {46, 26}}, color = {0, 0, 127}));
    connect(rigthHeartPart1.ExtP, leftHeartPart1.ExtP) annotation(Line(points = {{-76, 26}, {-86, 26}, {-86, 6}, {34, 6}, {34, 24}, {46, 24}, {46, 26}}, color = {0, 0, 127}));
    connect(arterial1.bfc_out1, tissues1.bfc_in1) annotation(Line(points = {{37, -59}, {18, -59}}));
    connect(tissues1.bfc_out1, vena1.bfc_in1) annotation(Line(points = {{-12, -59}, {-29, -59}, {-29, -60}, {-36, -60}}));
    connect(arterial1.IntrathoracicPressure, const2.y) annotation(Line(points = {{66, -70}, {80, -70}, {80, -90}, {28, -90}, {28, 24}, {6, 24}, {6, 24}}, color = {0, 0, 127}));
    connect(circulation1.IntrathoracicPressure, const2.y) annotation(Line(points = {{-16, 90}, {0, 90}, {0, 54}, {28, 54}, {28, 24}, {6, 24}, {6, 24}}, color = {0, 0, 127}));
    connect(const2.y, leftHeartPart1.HR) annotation(Line(points = {{6, 24}, {28, 24}, {28, 46}, {46, 46}, {46, 46}}, color = {0, 0, 127}));
    connect(rigthHeartPart1.HR, leftHeartPart1.HR) annotation(Line(points = {{-76, 46}, {-90, 46}, {-90, 54}, {28, 54}, {28, 46}, {46, 46}, {46, 46}}, color = {0, 0, 127}));
    connect(circulation1.bfc_out1, leftHeartPart1.bfc_in1) annotation(Line(points = {{20, 78}, {32, 78}, {32, 36}, {44, 36}}));
    connect(leftHeartPart1.bfc_out1, arterial1.bfc_in1) annotation(Line(points = {{77, 36}, {88, 36}, {88, -59}, {69, -59}}));
    connect(rigthHeartPart1.bfc_out1, circulation1.bfc_in1) annotation(Line(points = {{-45, 36}, {-30, 36}, {-30, 78}, {-20, 78}}));
    connect(vena1.bfc_out1, rigthHeartPart1.bfc_in1) annotation(Line(points = {{-68, -60}, {-90, -60}, {-90, 36}, {-78, 36}}));
    connect(vena1.u, arterial1.IntrathoracicPressure) annotation(Line(points = {{-38, -70}, {-26, -70}, {-26, -90}, {80, -90}, {80, -70}, {66, -70}, {66, -70}}, color = {0, 0, 127}));
    annotation(uses(Modelica(version = "3.2.1")));end VanMeurs;
  annotation(uses(Modelica(version = "3.2.2")));
end Meurs;